﻿#===============================================================================
#	Get-WmiObject-Win32Product
#
#	指定したPCに対して Get-WmiObject を実行し、インストールされたソフトの一覧を得る。
#	この時必要な項目は Select-Object で絞り込む。
#===============================================================================
Function Get-WmiObject-Win32Product($PcName, $User, $Password)
{
	$ret = $null
	
	try {
		if ($User -eq "") {
			$ret = Invoke-Command -ComputerName $PcName { Get-WmiObject -class win32_product }
		}
		else {
			#--- 平文のパスワードをCredentialとして使う手順
			$spw = ConvertTo-SecureString -AsPlainText $Password –Forc
			$cre = New-Object System.Management.Automation.PSCredential $User,$spw
			$ret = Invoke-Command -ComputerName $PcName -Credential $cre { Get-WmiObject -class win32_product }
		} 

		# 取得項目の絞り込み
		if ($ret -ne $null) {
			$ret = $ret | Select-Object PSComputerName, Name, Vendor, Version, InstallDate, IdentifyingNumber
		}
	}
	catch {
		$ret = $Error[0].ToString()
	}
	
	return $ret
}


#===============================================================================
#===============================================================================
$input | foreach {
	
	#--- 空欄を考慮し、確実に文字列に変換
	$PcName = [String]$_.PcName
	$User = [String]$_.User
	$Password = [String]$_.Password
	
	if ($PcName -ne "") {
		Get-WmiObject-Win32Product -PcName $PcName -User $User -Password $Password
		""
	}

}
